summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authordannye <33dannye@gmail.com>2020-12-20 14:11:21 -0600
committerdannye <33dannye@gmail.com>2020-12-20 14:11:21 -0600
commit9fab715759ddf919b0c4bb9a01095c4c225fcac0 (patch)
treed07d8bd6294c854061c521c4328f8f5ab62e830d /src
parentf7346b9491715307b31ff3d8003e16a976e60961 (diff)
Fix typos
Diffstat (limited to 'src')
-rw-r--r--src/constants/animation_constants.asm2
-rw-r--r--src/constants/hardware_constants.asm2
-rw-r--r--src/data/booster_packs.asm2
-rw-r--r--src/data/effect_commands.asm8
-rw-r--r--src/data/move_animations.asm2
-rw-r--r--src/engine/bank01.asm30
-rw-r--r--src/engine/bank04.asm14
-rw-r--r--src/engine/bank05.asm14
-rw-r--r--src/engine/bank06.asm2
-rw-r--r--src/engine/bank08.asm26
-rw-r--r--src/engine/booster_packs.asm2
-rw-r--r--src/engine/deck_ai/decks/legendary_articuno.asm2
-rw-r--r--src/engine/deck_ai/decks/legendary_dragonite.asm2
-rw-r--r--src/engine/deck_ai/decks/sams_practice.asm4
-rw-r--r--src/engine/effect_functions.asm18
-rw-r--r--src/engine/home.asm42
-rw-r--r--src/text/text1.asm2
-rw-r--r--src/text/text_offsets.asm2
-rw-r--r--src/wram.asm8
19 files changed, 92 insertions, 92 deletions
diff --git a/src/constants/animation_constants.asm b/src/constants/animation_constants.asm
index bdf93f8..645cb5e 100644
--- a/src/constants/animation_constants.asm
+++ b/src/constants/animation_constants.asm
@@ -2,7 +2,7 @@
ANIM_SPELL_MOVE EQU $01
ANIM_GET_HIT EQU $07
ANIM_THUNDER_SHOCK EQU $0a
-ANIM_FURY_SWEEPES EQU $24
+ANIM_FURY_SWIPES EQU $24
; Special animations
ANIM_SHOW_DAMAGE EQU $09
diff --git a/src/constants/hardware_constants.asm b/src/constants/hardware_constants.asm
index 3b36a9d..6879ffd 100644
--- a/src/constants/hardware_constants.asm
+++ b/src/constants/hardware_constants.asm
@@ -101,7 +101,7 @@ rNR34 EQU $ff1e ; Channel 3 Frequency's higher data (R/W)
rNR41 EQU $ff20 ; Channel 4 Sound Length (R/W)
rNR42 EQU $ff21 ; Channel 4 Volume Envelope (R/W)
rNR43 EQU $ff22 ; Channel 4 Polynomial Counter (R/W)
-rNR44 EQU $ff23 ; Channel 4 Counter/consecutive; Inital (R/W)
+rNR44 EQU $ff23 ; Channel 4 Counter/consecutive; Initial (R/W)
rNR50 EQU $ff24 ; Channel control / ON-OFF / Volume (R/W)
rNR51 EQU $ff25 ; Selection of Sound output terminal (R/W)
diff --git a/src/data/booster_packs.asm b/src/data/booster_packs.asm
index 8524ca6..44a401f 100644
--- a/src/data/booster_packs.asm
+++ b/src/data/booster_packs.asm
@@ -12,7 +12,7 @@ booster_set: MACRO
ENDM
; For the energy or energy generation function, there are three options:
-; - Ponter to a function that generates energies (some generate one, some generate a full pack)
+; - Pointer to a function that generates energies (some generate one, some generate a full pack)
; - A single energy of a specific type
; - $0000 if no card in the pack is an energy
diff --git a/src/data/effect_commands.asm b/src/data/effect_commands.asm
index 5d38cb4..f90fe80 100644
--- a/src/data/effect_commands.asm
+++ b/src/data/effect_commands.asm
@@ -11,7 +11,7 @@ EffectCommands: ; 186f7 (6:46f7)
; - EFFECTCMDTYPE_INITIAL_EFFECT_1: Executed right after move or trainer card is used. Bypasses Smokescreen and Sand Attack effects.
; - EFFECTCMDTYPE_INITIAL_EFFECT_2: Executed right after move, Pokemon Power, or trainer card is used.
; - EFFECTCMDTYPE_DISCARD_ENERGY: For moves or trainer cards that require putting one or more attached energy cards into the discard pile.
-; - EFFECTCMDTYPE_REQUIRE_SELECTION: For moves, Pokemon Powers, or trainer cards requring the user to select a card (from e.g. play area screen or card list).
+; - EFFECTCMDTYPE_REQUIRE_SELECTION: For moves, Pokemon Powers, or trainer cards requiring the user to select a card (from e.g. play area screen or card list).
; - EFFECTCMDTYPE_BEFORE_DAMAGE: Effect command of a move executed prior to the damage step. For trainer card or Pokemon Power, usually the main effect.
; - EFFECTCMDTYPE_AFTER_DAMAGE: Effect command executed after the damage step.
; - EFFECTCMDTYPE_AI_SWITCH_DEFENDING_PKMN: For moves that may result in the defending Pokemon being switched out. Called only for AI-executed moves.
@@ -1215,7 +1215,7 @@ KangaskhanFetchEffectCommands:
db $00
KangaskhanCometPunchEffectCommands:
- dbw EFFECTCMDTYPE_BEFORE_DAMAGE, CometPunch_MultiplerEffect
+ dbw EFFECTCMDTYPE_BEFORE_DAMAGE, CometPunch_MultiplierEffect
dbw EFFECTCMDTYPE_AI, CometPunch_AIEffect
db $00
@@ -1230,7 +1230,7 @@ TaurosRampageEffectCommands:
db $00
DoduoFuryAttackEffectCommands:
- dbw EFFECTCMDTYPE_BEFORE_DAMAGE, FuryAttack_MultiplerEffect
+ dbw EFFECTCMDTYPE_BEFORE_DAMAGE, FuryAttack_MultiplierEffect
dbw EFFECTCMDTYPE_AI, FuryAttack_AIEffect
db $00
@@ -1500,7 +1500,7 @@ ImposterProfessorOakEffectCommands:
ComputerSearchEffectCommands:
dbw EFFECTCMDTYPE_INITIAL_EFFECT_1, ComputerSearch_HandDeckCheck
dbw EFFECTCMDTYPE_INITIAL_EFFECT_2, ComputerSearch_PlayerDiscardHandSelection
- dbw EFFECTCMDTYPE_BEFORE_DAMAGE, ComputerSearch_DiscardAddToHandEfect
+ dbw EFFECTCMDTYPE_BEFORE_DAMAGE, ComputerSearch_DiscardAddToHandEffect
dbw EFFECTCMDTYPE_REQUIRE_SELECTION, ComputerSearch_PlayerDeckSelection
db $00
diff --git a/src/data/move_animations.asm b/src/data/move_animations.asm
index 9ead157..222a6d7 100644
--- a/src/data/move_animations.asm
+++ b/src/data/move_animations.asm
@@ -391,7 +391,7 @@ MoveAnimation_53eb:
MoveAnimation_53f6:
anim_player ANIM_SPELL_MOVE
- anim_opponent ANIM_FURY_SWEEPES
+ anim_opponent ANIM_FURY_SWIPES
anim_opponent ANIM_GET_HIT
anim_normal ANIM_SHAKE1
anim_opponent ANIM_SHOW_DAMAGE
diff --git a/src/engine/bank04.asm b/src/engine/bank04.asm
index 7d84d19..e3f65f0 100644
--- a/src/engine/bank04.asm
+++ b/src/engine/bank04.asm
@@ -1087,7 +1087,7 @@ MultichoiceTextbox_ConfigTable_ChooseDeckToDuelAgainst: ;1224b
db $05, $02 ; cursor starting x, y
db $02 ; number of tiles the cursor moves per toggle
db $03 ; cursor max index
- db $0f ; curor image
+ db $0f ; cursor image
db $00, $00, $00 ; marker bytes -- end of config table
@@ -1104,7 +1104,7 @@ MultichoiceTextbox_ConfigTable_ChooseDeckStarterDeck: ;12264
db $05, $02 ; cursor starting x, y
db $02 ; number of tiles the cursor moves per toggle
db $03 ; cursor max index
- db $0f ; curor image
+ db $0f ; cursor image
db $00, $00, $00 ; marker bytes -- end of config table
@@ -1117,7 +1117,7 @@ SamNormalMultichoice_ConfigurationTable: ;1227d
db $0b, $02 ; cursor starting x, y
db $02 ; number of tiles the cursor moves per toggle
db $04 ; cursor max index
- db $0f ; curor image
+ db $0f ; cursor image
db $00, $00, $00 ; marker bytes -- end of config table
@@ -1130,7 +1130,7 @@ SamTutorialMultichoice_ConfigurationTable: ;1228e
db $07, $02 ; cursor starting x, y
db $02 ; number of tiles the cursor moves per toggle
db $08 ; cursor max index
- db $0f ; curor image
+ db $0f ; cursor image
db $00, $00, $00 ; marker bytes -- end of config table
@@ -1291,7 +1291,7 @@ Unknown_128fb: ; 128fb
Func_1296e: ; 1296e (4:696e)
INCROM $1296e, $1299f
-; creates a new entry in SpriteAnimBuffer, Alse loads the sprite if need be
+; creates a new entry in SpriteAnimBuffer, else loads the sprite if need be
CreateSpriteAndAnimBufferEntry: ; 1299f (4:699f)
push af
ld a, [wd5d7]
@@ -1550,7 +1550,7 @@ HandleAnimationFrame: ; 12b13 (4:6b13)
call GetAnimFramePointerFromOffset
inc de
ld a, [de]
- call SetAimationCounterAndLoop
+ call SetAnimationCounterAndLoop
jr c, .tryHandlingFrame
inc de
ld bc, SPRITE_ANIM_COORD_X
@@ -1608,7 +1608,7 @@ GetAnimFramePointerFromOffset: ; 12b6a (4:6b6a)
; Sets the animation counter for the current sprite. If the value is zero, loop the animation
; a - new animation counter
-SetAimationCounterAndLoop: ; 12b89 (4:6b89)
+SetAnimationCounterAndLoop: ; 12b89 (4:6b89)
push hl
push bc
ld bc, SPRITE_ANIM_COUNTER
diff --git a/src/engine/bank05.asm b/src/engine/bank05.asm
index 79c168f..2b59c96 100644
--- a/src/engine/bank05.asm
+++ b/src/engine/bank05.asm
@@ -1223,7 +1223,7 @@ LookForCardIDInHandList_Bank5: ; 155d2 (5:55d2)
; input:
; a = card ID
; b = PLAY_AREA_* to start with
-; ouput:
+; output:
; a = PLAY_AREA_* of found card
; carry set if found
LookForCardIDInPlayArea_Bank5: ; 155ef (5:55ef)
@@ -3972,7 +3972,7 @@ AIProcessButDontPlayEnergy_SkipEvolutionAndArena: ; 164ba (5:64ba)
jr AIProcessEnergyCards
; copies wTempPlayAreaAIScore to wPlayAreaAIScore
-; and loads wAIscore with value in wTempAIScore.
+; and loads wAIScore with value in wTempAIScore.
; identical to RetrievePlayAreaAIScoreFromBackup2.
RetrievePlayAreaAIScoreFromBackup1: ; 164d3 (5:64d3)
push af
@@ -4611,7 +4611,7 @@ CheckIfEvolutionNeedsEnergyForMove: ; 16805 (5:6805)
; returns in e the card ID of the energy required for
; the Discard/Energy Boost attack loaded in wSelectedAttack.
; if it's Zapdos2's Thunderbolt attack, return no carry.
-; if it's Charizard's Fire Spin or Exeggutor's Big Eggplosion
+; if it's Charizard's Fire Spin or Exeggutor's Big Eggsplosion
; attack, don't return energy card ID, but set carry.
; output:
; b = 1 if needs color energy, 0 otherwise;
@@ -4879,7 +4879,7 @@ CheckSpecificDecksToAttachDoubleColorless: ; 1696e (5:696e)
push de
push hl
-; check if AI is playing any of the aplicable decks.
+; check if AI is playing any of the applicable decks.
ld a, [wOpponentDeckID]
cp LEGENDARY_DRAGONITE_DECK_ID
jr z, .legendary_dragonite_deck
@@ -4974,7 +4974,7 @@ AIProcessButDontUseAttack: ; 169ca (5:69ca)
jr AIProcessAttacks
; copies wTempPlayAreaAIScore to wPlayAreaAIScore
-; and loads wAIscore with value in wTempAIScore.
+; and loads wAIScore with value in wTempAIScore.
; identical to RetrievePlayAreaAIScoreFromBackup1.
RetrievePlayAreaAIScoreFromBackup2: ; 169e3 (5:69e3)
push af
@@ -6630,7 +6630,7 @@ CheckCardEvolutionInHandOrDeck: ; 17274 (5:7274)
scf
ret
-; sets up the inital hand of boss deck.
+; sets up the initial hand of boss deck.
; always draws at least 2 Basic Pokemon cards and 2 Energy cards.
; also sets up so that the next cards to be drawn have
; some minimum number of Basic Pokemon and Energy cards.
@@ -7221,7 +7221,7 @@ Func_174f2: ; 174f2 (5:74f2)
jp .loop_play_area
; loads wcdea + play area location in e
-; with nenergy * 2 + $80 - floor(dam / 10)
+; with energy * 2 + $80 - floor(dam / 10)
; loads wcdfa + play area location in e
; with $01
Func_17583: ; 17583 (5:7583)
diff --git a/src/engine/bank06.asm b/src/engine/bank06.asm
index 9c8d24f..4dcad9d 100644
--- a/src/engine/bank06.asm
+++ b/src/engine/bank06.asm
@@ -915,7 +915,7 @@ OpenGlossaryScreen: ; 184c8 (6:44c8)
; unit: 5 bytes.
; [structure]
-; horizonal align (1) / title text id (2) / desc. text id (2)
+; horizontal align (1) / title text id (2) / desc. text id (2)
glossary_entry: MACRO
db \1
tx \2
diff --git a/src/engine/bank08.asm b/src/engine/bank08.asm
index 5283497..d674a9c 100644
--- a/src/engine/bank08.asm
+++ b/src/engine/bank08.asm
@@ -974,7 +974,7 @@ AIDecide_Pluspower2: ; 205a5 (8:45a5)
; return carry if move is useable but cannot KO.
.check_can_ko ; 205d7 (8:45d7)
farcall CheckIfSelectedMoveIsUnusable
- jr c, .unuseable
+ jr c, .unusable
ld a, [wSelectedAttack]
farcall EstimateDamage_VersusDefendingCard
ld a, DUELVARS_ARENA_CARD_HP
@@ -987,7 +987,7 @@ AIDecide_Pluspower2: ; 205a5 (8:45a5)
; can't KO.
scf
ret
-.unuseable
+.unusable
or a
ret
@@ -995,12 +995,12 @@ AIDecide_Pluspower2: ; 205a5 (8:45a5)
; move is useable and minimum damage > 0.
.check_random ; 205f6 (8:45f6)
farcall CheckIfSelectedMoveIsUnusable
- jr c, .unuseable
+ jr c, .unusable
ld a, [wSelectedAttack]
farcall EstimateDamage_VersusDefendingCard
ld a, [wAIMinDamage]
cp 10
- jr c, .unuseable
+ jr c, .unusable
ld a, 10
call Random
cp 3
@@ -3559,7 +3559,7 @@ AIDecide_Pokedex: ; 212dc (8:52dc)
jp PickPokedexCards ; bug, should be jp nz
; picks order of the cards in deck from the effects of Pokedex.
-; prioritises Pokemon cards, then Trainer cards, then energy cards.
+; prioritizes Pokemon cards, then Trainer cards, then energy cards.
; stores the resulting order in wce1a.
PickPokedexCards_Unreferenced: ; 212ff (8:52ff)
; unreferenced
@@ -3690,7 +3690,7 @@ PickPokedexCards_Unreferenced: ; 212ff (8:52ff)
ret
; picks order of the cards in deck from the effects of Pokedex.
-; prioritises energy cards, then Pokemon cards, then Trainer cards.
+; prioritizes energy cards, then Pokemon cards, then Trainer cards.
; stores the resulting order in wce1a.
PickPokedexCards: ; 2138e (8:538e)
xor a
@@ -4168,7 +4168,7 @@ AIDecide_ScoopUp: ; 21506 (8:5506)
scf
ret
-; this deck will use Scoop Up on a benched Articuno2, Zapdos3 or Molres2.
+; this deck will use Scoop Up on a benched Articuno2, Zapdos3 or Moltres2.
; interestingly, does not check for Muk in both Play Areas.
.HandleLegendaryRonald ; 215e7 (8:55e7)
; if less than 3 Play Area Pokemon cards, skip.
@@ -6042,7 +6042,7 @@ AIDecide_PokemonTrader_FlowerGarden: ; 220a8 (8:60a8)
AIDecide_PokemonTrader_StrangePower: ; 22122 (8:6122)
; looks for a Pokemon in hand to trade with Mr Mime in deck.
-; inputing Mr Mime in register e for the function is redundant
+; inputting Mr Mime in register e for the function is redundant
; since it already checks whether a Mr Mime exists in the hand.
ld a, MR_MIME
ld e, MR_MIME
@@ -6764,7 +6764,7 @@ HandleAIShift: ; 22476 (8:6476)
ld a, OPPACTION_USE_PKMN_POWER
bank1call AIMakeDecision
-; converts WR_* to apropriate color
+; converts WR_* to appropriate color
ld a, [wAIDefendingPokemonWeakness]
ld b, 0
.loop_color
@@ -7535,7 +7535,7 @@ AIPickEnergyCardToDiscard: ; 2282e (8:682e)
; returns in a the deck index of an energy card attached to card
; in player's Play Area location a to remove.
-; prioritises double colorless energy, then any useful energy,
+; prioritizes double colorless energy, then any useful energy,
; then defaults to the first energy card attached if neither
; of those are found.
; returns $ff in a if there are no energy cards attached.
@@ -7614,7 +7614,7 @@ PickAttachedEnergyCardToRemove: ; 22875 (8:6875)
; stores in wTempAI and wCurCardCanAttack the deck indices
; of energy cards attached to card in Play Area location a.
-; prioritises double colorless energy, then any useful energy,
+; prioritizes double colorless energy, then any useful energy,
; then defaults to the first two energy cards attached if neither
; of those are found.
; returns $ff in a if there are no energy cards attached.
@@ -8014,7 +8014,7 @@ LookForCardIDInDeck_GivenCardIDInHand: ; 22a49 (8:6a49)
; input:
; a = card ID
; b = PLAY_AREA_* to start with
-; ouput:
+; output:
; a = PLAY_AREA_* of found card
; carry set if found
LookForCardIDInPlayArea_Bank8: ; 22a72 (8:6a72)
@@ -8134,7 +8134,7 @@ RemoveFromListDifferentCardOfGivenType: ; 22a95 (8:6a95)
; e = card ID 2
; output:
; a = deck index of card ID 1 found in deck
-; e = deck index of Pokemon card in hand dfferent than card ID 2
+; e = deck index of Pokemon card in hand different than card ID 2
LookForCardIDToTradeWithDifferentHandCard: ; 22ae0 (8:6ae0)
ld hl, wCurCardCanAttack
ld [hl], e
diff --git a/src/engine/booster_packs.asm b/src/engine/booster_packs.asm
index 238a8b2..25acec1 100644
--- a/src/engine/booster_packs.asm
+++ b/src/engine/booster_packs.asm
@@ -452,7 +452,7 @@ PutEnergiesAndNonEnergiesTogether: ; 1e3f3 (7:63f3)
pop hl
ret
-; add the final cards drawn from the booster pack to the player's colection (sCardCollection)
+; add the final cards drawn from the booster pack to the player's collection (sCardCollection)
AddBoosterCardsToCollection: ; 1e40a (7:640a)
push hl
ld hl, wBoosterCardsDrawn
diff --git a/src/engine/deck_ai/decks/legendary_articuno.asm b/src/engine/deck_ai/decks/legendary_articuno.asm
index 62ee246..562e7c5 100644
--- a/src/engine/deck_ai/decks/legendary_articuno.asm
+++ b/src/engine/deck_ai/decks/legendary_articuno.asm
@@ -78,7 +78,7 @@ AIActionTable_LegendaryArticuno: ; 14c0b (5:4c0b)
ret
; this routine handles how Legendary Articuno
-; prioritises playing energy cards to each Pokémon.
+; prioritizes playing energy cards to each Pokémon.
; first, it makes sure that all Lapras have at least
; 3 energy cards before moving on to Articuno,
; and then to Dewgong and Seel
diff --git a/src/engine/deck_ai/decks/legendary_dragonite.asm b/src/engine/deck_ai/decks/legendary_dragonite.asm
index 7090e50..2b8cef6 100644
--- a/src/engine/deck_ai/decks/legendary_dragonite.asm
+++ b/src/engine/deck_ai/decks/legendary_dragonite.asm
@@ -105,7 +105,7 @@ AIDoTurn_LegendaryDragonite: ; 14def (5:4def)
or a
jr nz, .skip_energy_attach_1
-; if Arena card is Kangaskhan and doens't
+; if Arena card is Kangaskhan and doesn't
; have Energy cards attached, try attaching from hand.
; otherwise run normal AI energy attach routine.
ld a, DUELVARS_ARENA_CARD
diff --git a/src/engine/deck_ai/decks/sams_practice.asm b/src/engine/deck_ai/decks/sams_practice.asm
index b7642a8..10ce811 100644
--- a/src/engine/deck_ai/decks/sams_practice.asm
+++ b/src/engine/deck_ai/decks/sams_practice.asm
@@ -15,7 +15,7 @@ AIActionTable_SamPractice: ; 147bd (05:47bd)
call AIMainTurnLogic
ret
.scripted_1 ; use scripted actions instead
- call AIPerformSciptedTurn
+ call AIPerformScriptedTurn
ret
.start_duel ; 147d6 (5:47d6)
@@ -93,7 +93,7 @@ GetPlayAreaLocationOfRaticateOrRattata: ; 1481f (5:481f)
ret
; has AI execute some scripted actions depending on Duel turn.
-AIPerformSciptedTurn: ; 1483a (5:483a)
+AIPerformScriptedTurn: ; 1483a (5:483a)
ld a, [wDuelTurns]
srl a
ld hl, .scripted_actions_list
diff --git a/src/engine/effect_functions.asm b/src/engine/effect_functions.asm
index 77c0375..92a1f3d 100644
--- a/src/engine/effect_functions.asm
+++ b/src/engine/effect_functions.asm
@@ -4728,7 +4728,7 @@ Curse_TransferDamageEffect: ; 2d8bb (b:58bb)
cp DUELIST_TYPE_PLAYER
jr z, .vs_player
-; vs. oppponent
+; vs. opponent
bank1call Func_61a1
.vs_player
; transfer the damage counter to the targets that were selected.
@@ -5608,7 +5608,7 @@ HandleEvolvedCardSelection: ; 2dd50 (b:5d50)
ret
; 0x2dd62
-; finds first occurence in Play Area
+; finds first occurrence in Play Area
; of Stage 1 or 2 card, and outputs its
; Play Area location in a, with carry set.
; if none found, don't return carry set.
@@ -5799,7 +5799,7 @@ StrangeBehavior_CheckDamage: ; 2de39 (b:5e39)
call CheckIfPlayAreaHasAnyDamage
ldtx hl, NoPokemonWithDamageCountersText
jr c, .set_carry
-; can Slowbro receive any damage counters without KOing?
+; can Slowbro receive any damage counters without KO-ing?
ldh a, [hTempPlayAreaLocation_ff9d]
add DUELVARS_ARENA_CARD_HP
call GetTurnDuelistVariable
@@ -7925,12 +7925,12 @@ MirrorMoveEffects: ; 2e98c (b:698c)
or a
ret z ; no effect
cp LAST_TURN_EFFECT_DISCARD_ENERGY
- jr z, .dicard_energy
+ jr z, .discard_energy
cp LAST_TURN_EFFECT_AMNESIA
jr z, .pick_amnesia_attack
ret
-.dicard_energy
+.discard_energy
call AIPickEnergyCardToDiscardFromDefendingPokemon
ldh [hTemp_ffa0], a
ret
@@ -8209,7 +8209,7 @@ CometPunch_AIEffect: ; 2eb5d (b:6b5d)
jp SetExpectedAIDamage
; 0x2eb65
-CometPunch_MultiplerEffect: ; 2eb65 (b:6b65)
+CometPunch_MultiplierEffect: ; 2eb65 (b:6b65)
ld hl, 20
call LoadTxRam3
ldtx de, DamageCheckIfHeadsXDamageText
@@ -8264,7 +8264,7 @@ FuryAttack_AIEffect: ; 2ebba (b:6bba)
jp SetExpectedAIDamage
; 0x2ebc2
-FuryAttack_MultiplerEffect: ; 2ebc2 (b:6bc2)
+FuryAttack_MultiplierEffect: ; 2ebc2 (b:6bc2)
ld hl, 10
call LoadTxRam3
ld a, 2
@@ -9976,7 +9976,7 @@ ComputerSearch_PlayerDeckSelection: ; 2f52e (b:752e)
ret
; 0x2f545
-ComputerSearch_DiscardAddToHandEfect: ; 2f545 (b:7545)
+ComputerSearch_DiscardAddToHandEffect: ; 2f545 (b:7545)
; discard cards from hand
ld hl, hTempList
ld a, [hli]
@@ -11215,7 +11215,7 @@ CreateBasicPokemonCardListFromDiscardPile: ; 2fbd6 (b:7bd6)
or a
jr nz, .next_discard_pile_card ; if not Basic stage, skip
-; write this card'sindex to wDuelTempList
+; write this card's index to wDuelTempList
ld a, [hl]
ld [de], a
inc de
diff --git a/src/text/text1.asm b/src/text/text1.asm
index fa1d585..93c389f 100644
--- a/src/text/text1.asm
+++ b/src/text/text1.asm
@@ -372,7 +372,7 @@ ChooseTheCardYouWishToExamineText: ; 3697c (d:697c)
line "you wish to examine."
done
-TransmitingDataText: ; 369a2 (d:69a2)
+TransmittingDataText: ; 369a2 (d:69a2)
text "Transmitting data..."
done
diff --git a/src/text/text_offsets.asm b/src/text/text_offsets.asm
index b44dc3e..23a7ddf 100644
--- a/src/text/text_offsets.asm
+++ b/src/text/text_offsets.asm
@@ -88,7 +88,7 @@ TextOffsets:: ; 34000 (d:4000)
textpointer YouPlaySecondText ; 0x0054
textpointer TransmissionErrorText ; 0x0055
textpointer ChooseTheCardYouWishToExamineText ; 0x0056
- textpointer TransmitingDataText ; 0x0057
+ textpointer TransmittingDataText ; 0x0057
textpointer WaitingHandExamineText ; 0x0058
textpointer SelectingBenchPokemonHandExamineBackText ; 0x0059
textpointer RetreatedToTheBenchText ; 0x005a
diff --git a/src/wram.asm b/src/wram.asm
index a3c44d0..dc1d91f 100644
--- a/src/wram.asm
+++ b/src/wram.asm
@@ -733,7 +733,7 @@ wNoItemSelectionMenuKeys:: ; cbd6
ds $1
; when viewing a card page, which keys (among B_BUTTON, D_UP, and D_DOWN) will exit the page,
-; either to go back to the previous menu orlist, or to load the card page of the card above/below it
+; either to go back to the previous menu or list, or to load the card page of the card above/below it
wCardPageExitKeys:: ; cbd7
ds $1
@@ -2085,10 +2085,10 @@ wBoosterViableCardList:: ; d133
NEXTU
-; permission map of the current room with unpassable objects (walls, NPCs, etc).
+; permission map of the current room with impassable objects (walls, NPCs, etc).
; $00: passable (floor)
-; $40: unpassable and talkable (NPC or talkable wall)
-; $80: unpassable and untalkable (wall)
+; $40: impassable and talkable (NPC or talkable wall)
+; $80: impassable and untalkable (wall)
wPermissionMap:: ; d133
ds $100
diff --git a/src/engine/bank01.asm b/src/engine/bank01.asm
index 556f2cd..a7184a6 100644
--- a/src/engine/bank01.asm
+++ b/src/engine/bank01.asm
@@ -187,7 +187,7 @@ MainDuelLoop: ; 40ee (1:40ee)
cp TURN_PLAYER_WON
jr z, .active_duelist_won_battle
cp TURN_PLAYER_LOST
- jr z, .active_duelist_lost_batte
+ jr z, .active_duelist_lost_battle
ld a, $5f
ld c, MUSIC_DARK_DIDDLY
ldtx hl, DuelWasADrawText
@@ -205,7 +205,7 @@ MainDuelLoop: ; 40ee (1:40ee)
ldtx hl, WonDuelText
jr .handle_duel_finished
-.active_duelist_lost_batte
+.active_duelist_lost_battle
ldh a, [hWhoseTurn]
cp PLAYER_TURN
jr nz, .player_won_battle
@@ -779,7 +779,7 @@ PlayPokemonCard: ; 44db (1:44db)
ldh a, [hTempPlayAreaLocation_ff9d]
ldh [hTempPlayAreaLocation_ffa1], a
call EvolvePokemonCardIfPossible
- jr c, .try_evolve_loop ; jump if evolution wasn't successsful somehow
+ jr c, .try_evolve_loop ; jump if evolution wasn't successful somehow
ld a, OPPACTION_EVOLVE_PKMN
call SetOppAction_SerialSendDuelData
call PrintPlayAreaCardList_EnableLCD
@@ -1554,7 +1554,7 @@ PrintDeckAndHandIconsAndNumberOfCards: ; 49ca (1:49ca)
; prints, for each duelist, the number of cards in the hand, and the number
; of cards in the deck, according to their placement in the draw card(s) screen.
; input: wNumCardsBeingDrawn = number of cards being drawn (in order to add
; them to the hand cards and substract them from the deck cards).
PrintNumberOfHandAndDeckCards: ; 49ed (1:49ed)
ldh a, [hWhoseTurn]
cp PLAYER_TURN
@@ -1948,7 +1948,7 @@ ChooseInitialArenaAndBenchPokemon: ; 4cd5 (1:4cd5)
; link opponent's turn
.exchange_duelvars
- ldtx hl, TransmitingDataText
+ ldtx hl, TransmittingDataText
call DrawWideTextBox_PrintText
call ExchangeRNG
ld hl, wPlayerDuelVariables
@@ -2580,7 +2580,7 @@ DrawDuelHUD: ; 5093 (1:5093)
.done
ret
-; draws an horizonal line that separates the arena side of each duelist
+; draws an horizontal line that separates the arena side of each duelist
; also colorizes the line on CGB
DrawDuelHorizontalSeparator: ; 516f (1:516f)
ld hl, DuelHorizontalSeparatorTileData
@@ -3211,7 +3211,7 @@ Func_5591: ; 5591 (1:5591)
; Discard Pile card list, including a bottom-right image of the current card.
; since this loads the text for the Hand card list screen, SetDiscardPileScreenTexts
; is called after this if the screen corresponds to a Discard Pile list.
-; the dimensions of text box where the card list is printed are 20x13, in order to accomodate
+; the dimensions of text box where the card list is printed are 20x13, in order to accommodate
; another text box below it (wCardListInfoBoxText) as well as the image of the selected card.
InitAndDrawCardListScreenLayout: ; 559a (1:559a)
xor a
@@ -3446,7 +3446,7 @@ CardListItemSelectionMenu: ; 56c2 (1:56c2)
ret
ItemSelectionMenuParameters: ; 5708 (1:5708)
- db 1, 14 ; corsor x, cursor y
+ db 1, 14 ; cursor x, cursor y
db 2 ; y displacement between items
db 2 ; number of items
db SYM_CURSOR_R ; cursor tile number
@@ -3792,7 +3792,7 @@ GoToFirstOrNextCardPage: ; 58e2 (1:58e2)
; stay in this page if it exists, or skip to previous page if it doesn't
or a
ret nz
- ; non-existant page: skip to next
+ ; non-existent page: skip to next
jr .advance_page
.set_card_page
ld [wCardPageNumber], a
@@ -3809,7 +3809,7 @@ GoToPreviousCardPage: ; 5911 (1:5911)
; stay in this page if it exists, or skip to previous page if it doesn't
or a
ret nz
- ; non-existant page: skip to previous
+ ; non-existent page: skip to previous
jr GoToPreviousCardPage
.set_card_page
ld [wCardPageNumber], a
@@ -3828,7 +3828,7 @@ GoToPreviousCardPage: ; 5911 (1:5911)
; return with the equivalent to one of these three actions:
; stay in card page trying to switch to (nc, nz)
; change to card page returned in a if D_LEFT/D_RIGHT pressed, or exit if A_BUTTON/START pressed (c)
- ; non-existant page, so skip to next/previous (nc, z)
+ ; non-existent page, so skip to next/previous (nc, z)
SwitchCardPage: ; 5930 (1:5930)
ld hl, CardPageSwitchPointerTable
jp JumpToFunctionInTable
@@ -5827,10 +5827,10 @@ TwoByteNumberToTxSymbol_TrimLeadingZeros_Bank1: ; 65d1 (1:65d1)
.get_digit
ld a, SYM_0 - 1
-.substract_loop
+.subtract_loop
inc a
add hl, bc
- jr c, .substract_loop
+ jr c, .subtract_loop
ld [de], a
inc de
ld a, l
@@ -6987,7 +6987,7 @@ Func_6d3f: ; 6d3f (1:6d3f)
ld d, $00
ld a, DUELVARS_ARENA_CARD_HP
call GetTurnDuelistVariable
- call SubstractHP
+ call SubtractHP
push hl
ld a, $8c
call Func_6cab
@@ -8120,7 +8120,7 @@ PlayAttackAnimation_DealAttackDamageSimple: ; 7469 (1:7469)
call WaitMoveAnimation
pop de
pop hl
- call SubstractHP
+ call SubtractHP
ld a, [wDuelDisplayedScreen]
cp DUEL_MAIN_SCENE
ret nz
@@ -1554,7 +1554,7 @@ PrintDeckAndHandIconsAndNumberOfCards: ; 49ca (1:49ca)
; of cards in the deck, according to their placement in the draw card(s) screen.
; input: wNumCardsBeingDrawn = number of cards being drawn (in order to add
-; them to the hand cards and substract them from the deck cards).
+; them to the hand cards and subtract them from the deck cards).
PrintNumberOfHandAndDeckCards: ; 49ed (1:49ed)
ldh a, [hWhoseTurn]
diff --git a/src/engine/home.asm b/src/engine/home.asm
index 140fcc9..a5125c4 100644
--- a/src/engine/home.asm
+++ b/src/engine/home.asm
@@ -579,7 +579,7 @@ FlushAllCGBPalettes: ; 0458 (0:0458)
jr FlushPalettesIfRequested.done
; copy b bytes of CGB palette data starting at
-; (wBackgroundPalettesCGB + a palettes) into rBGPD or rOGPD.
+; (wBackgroundPalettesCGB + a palettes) into rBGPD or rOBPD.
CopyCGBPalettes: ; 0467 (0:0467)
add a
add a
@@ -1007,10 +1007,10 @@ TwoByteNumberToText: ; 0663 (0:0663)
ret
.get_digit
ld a, "0" - 1
-.substract_loop
+.subtract_loop
inc a
add hl, bc
- jr c, .substract_loop
+ jr c, .subtract_loop
ld [de], a
inc de
ld a, l
@@ -1175,7 +1175,7 @@ CopyGfxData: ; 070c (0:070c)
jr nz, .next_tile
ret
-; copy bc bytes from hl to de. preserves all regsters except af
+; copy bc bytes from hl to de. preserves all registers except af
CopyDataHLtoDE_SaveRegisters: ; 0732 (0:0732)
push hl
push de
@@ -2036,10 +2036,10 @@ MltReq2Packet: ; 0bbb (0:0bbb)
Func_0bcb: ; 0bcb (0:0bcb)
di
push de
-.wait_vbalnk
+.wait_vblank
ldh a, [rLY]
cp LY_VBLANK + 3
- jr nz, .wait_vbalnk
+ jr nz, .wait_vblank
ld a, LCDC_BGON | LCDC_OBJON | LCDC_WIN9C00
ldh [rLCDC], a
ld a, %11100100
@@ -2779,7 +2779,7 @@ ExchangeRNG: ; 0f58 (0:0f58)
; hTemp_ffa0, and hTempPlayAreaLocation_ffa1, and hTempRetreatCostCards.
; finally exchange RNG data.
; the receiving side will use this data to read the OPPACTION_* value in
-; [hOppActionTableIndex] and match it by calling the correspoding OppAction* function
+; [hOppActionTableIndex] and match it by calling the corresponding OppAction* function
SetOppAction_SerialSendDuelData: ; 0f7f (0:0f7f)
push hl
push bc
@@ -3031,7 +3031,7 @@ ShuffleDeck: ; 10bc (0:10bc)
ret
; draw a card from the turn holder's deck, saving its location as CARD_LOCATION_JUST_DRAWN.
-; returns carry if deck is empty, nc if a card was succesfully drawn.
+; returns carry if deck is empty, nc if a card was successfully drawn.
; AddCardToHand is meant to be called next (unless this function returned carry).
DrawCardFromDeck: ; 10cf (0:10cf)
push hl
@@ -4466,7 +4466,7 @@ PlayAttackAnimation_DealAttackDamage: ; 179a (0:179a)
call WaitMoveAnimation
pop hl
pop de
- call SubstractHP
+ call SubtractHP
ld a, [wDuelDisplayedScreen]
cp DUEL_MAIN_SCENE
jr nz, .skip_draw_huds
@@ -4899,10 +4899,10 @@ ApplyAttachedDefender: ; 1a7e (0:1a7e)
ld d, a
ret
; hl: address to substract HP from
; de: how much HP to substract (damage to deal)
; returns carry if the HP does not become 0 as a result
-SubstractHP: ; 1a96 (0:1a96)
+SubtractHP: ; 1a96 (0:1a96)
push hl
push de
ld a, [hl]
@@ -6146,7 +6146,7 @@ LoadDuelCardSymbolTiles2: ; 20c4 (0:20c4)
ld b, $c
jr CopyFontsOrDuelGraphicsTiles
-; load the face down basic / stage1 / stage2 card images shown in the ckeck Pokemon screens
+; load the face down basic / stage1 / stage2 card images shown in the check Pokemon screens
LoadDuelFaceDownCardTiles: ; 20d8 (0:20d8)
ld b, $10
jr LoadDuelCheckPokemonScreenTiles.got_num_tiles
@@ -6239,7 +6239,7 @@ Func_212f: ; 212f (0:212f)
ld b, $30
jr CopyFontsOrDuelGraphicsTiles
-; load the graphics and draw the duel box message given a BOXMSC_* constant in a
+; load the graphics and draw the duel box message given a BOXMSG_* constant in a
DrawDuelBoxMessage: ; 2167 (0:2167)
ld l, a
ld h, 40 tiles / 4 ; boxes are 10x4 tiles
@@ -6888,10 +6888,10 @@ TwoByteNumberToTxSymbol_TrimLeadingZeros: ; 245d (0:245d)
ld [de], a
inc de
ld a, SYM_0 - 1
-.substract_loop
+.subtract_loop
inc a
add hl, bc
- jr c, .substract_loop
+ jr c, .subtract_loop
ld [de], a
inc de
ld a, l
@@ -7978,7 +7978,7 @@ DrawNarrowTextBox_WaitForInput: ; 2a7c (0:2a7c)
ret
NarrowTextBoxMenuParameters: ; 2a96 (0:2a96)
- db 10, 17 ; corsor x, cursor y
+ db 10, 17 ; cursor x, cursor y
db 1 ; y displacement between items
db 1 ; number of items
db SYM_CURSOR_D ; cursor tile number
@@ -9138,7 +9138,7 @@ AddToDamage: ; 3055 (0:3055)
ret
; [wDamage] -= a
-SubstractFromDamage: ; 3061 (0:3061)
+SubtractFromDamage: ; 3061 (0:3061)
push de
push hl
ld e, a
@@ -9662,7 +9662,7 @@ HandleStrikesBack_AgainstDamagingMove: ; 3317 (0:3317)
.in_bench
push hl
push de
; substract 10 HP from attacking Pokemon (turn holder's arena Pokemon)
call SwapTurn
ld a, DUELVARS_ARENA_CARD
call GetTurnDuelistVariable
@@ -9672,7 +9672,7 @@ HandleStrikesBack_AgainstDamagingMove: ; 3317 (0:3317)
push af
push hl
ld de, 10
- call SubstractHP
+ call SubtractHP
ld a, [wLoadedCard2ID]
ld [wTempNonTurnDuelistCardID], a
ld hl, 10
@@ -10271,7 +10271,7 @@ ApplyStrikesBack_AgainstResidualMove: ; 36a2 (0:36a2)
pop de
push af
push hl
- call SubstractHP
+ call SubtractHP
ldtx hl, ReceivesDamageDueToStrikesBackText
call DrawWideTextBox_PrintText
pop hl
@@ -4899,10 +4899,10 @@ ApplyAttachedDefender: ; 1a7e (0:1a7e)
ld d, a
ret
-; hl: address to substract HP from
-; de: how much HP to substract (damage to deal)
+; hl: address to subtract HP from
+; de: how much HP to subtract (damage to deal)
; returns carry if the HP does not become 0 as a result
@@ -9662,7 +9662,7 @@ HandleStrikesBack_AgainstDamagingMove: ; 3317 (0:3317)
push hl
push de
- ; substract 10 HP from attacking Pokemon (turn holder's arena Pokemon)
+ ; subtract 10 HP from attacking Pokemon (turn holder's arena Pokemon)
call SwapTurn
ld a, DUELVARS_ARENA_CARD